.. django-icetea documentation master file, created by
   sphinx-quickstart on Mon Mar 19 12:07:32 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-icetea's documentation!
=========================================

Framework for creating RESTful APIs, in an intuitive, maintainable secure way.
Aims at providing a lot of functionality out of the box, so that the developer
can lay the foundation of the API quickly, and focus on the business logic of
the application.

Please refer to the project's `Github repository <https://github.com/stargazer/django-icetea>`_ for code and detailed documentation.

.. automodule:: icetea
    :members:


:mod:`~icetea.resource`
-------------------------

.. autoclass:: icetea.resource.Resource
    :members:
    :undoc-members:
    :member-order: bysource
 

:mod:`~icetea.handlers`
-----------------------

.. autoclass:: icetea.handlers.BaseHandler
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: icetea.handlers.ModelHandler
    :members:
    :member-order: bysource

  
:mod:`~icetea.custom_filters`
-------------------------------
.. automodule:: icetea.custom_filters
    :members:
    :undoc-members:
    :member-order: bysource

:mod:`~icetea.tests`
-------------------------------
.. automodule:: icetea.tests
	:members:
	:undoc-members:
	:member-order: bysource



